@@ -3,6 +3,7 @@ Unit Tests for constants
 """
 
 import unittest
+
 from logria.utilities import constants
 
 
@@ -28,10 +29,12 @@ class TestFormattingFunctions(unittest.TestCase):
         """
         Ensure SAVED_PATTERNS_PATH is the expected value
         """
-        self.assertEqual(constants.SAVED_PATTERNS_PATH, f'{constants.USER_HOME}/.logria/patterns')
+        self.assertEqual(constants.SAVED_PATTERNS_PATH,
+                         f'{constants.USER_HOME}/.logria/patterns')
 
     def test_saved_sessions_path(self):
         """
         Ensure SAVED_SESSIONS_PATH is the expected value
         """
-        self.assertEqual(constants.SAVED_SESSIONS_PATH, f'{constants.USER_HOME}/.logria/sessions')
+        self.assertEqual(constants.SAVED_SESSIONS_PATH,
+                         f'{constants.USER_HOME}/.logria/sessions')
